#!/usr/bin/python3
import rospy
import cv2
# ROS Image message
from sensor_msgs.msg import Image
# ROS Image message -> OpenCV2 image converter
from cv_bridge import CvBridge, CvBridgeError
# OpenCV2 for saving an image

# Instantiate CvBridge
bridge = CvBridge()

def image_callback(msg):
    try:
        # Convert your ROS Image message to OpenCV2
        cv2_img = bridge.imgmsg_to_cv2(msg, "bgr8")
        rospy.loginfo("received new image.")
        # Save your OpenCV2 image as a jpeg
        cv2.imwrite('/home/llh/sarwebui/media/droneimages/camera_image.jpeg', cv2_img)
    except CvBridgeError as e:
        print(e)

def main():
    rospy.init_node('image_handler')

    # Define your image topic
    if (rospy.get_param('camera_type') == 0):
        image_topic = "dji_osdk_ros/fpv_camera_images"
    else:
        image_topic = "dji_osdk_ros/main_camera_images"
    # Set up your subscriber and define its callback
    rospy.Subscriber(image_topic, Image, image_callback)
    # Spin until ctrl + c
    rospy.loginfo("image handler ready for images...")
    rospy.spin()

if __name__ == '__main__':
    main()
